import os
from django.core.mail import EmailMessage
import codecs
import sys

SENDER_EMAIL = os.getenv('SENDER_MAIL', 'kepzes@kszk.bme.hu')
HOMEWORK_LINK = os.getenv(
    'HOMEWORK_LINK', 'https://ujonc.kszk.bme.hu/homework')


def get_full_name(user):
    return user.last_name + " " + user.first_name


def read_email(name):
    with codecs.open('common/emails/' + name, 'r', 'utf-8') as myfile:
        data = myfile.read()
    return data


def send_out_mail(subject, message, SENDER_EMAIL, receiver_email):
    if 'runserver' in sys.argv:
        # It is in development
        print("Email sent from: " + str(SENDER_EMAIL) +
              " to: " + str(receiver_email[0]))
    else:
        email = EmailMessage(
            subject=subject,
            body=message,
            from_email=SENDER_EMAIL,
            to=[receiver_email, ],
            reply_to=[SENDER_EMAIL]
        )
        email.send()


def registration(user):
    subject = "KSZKépzés regisztráció"
    message = read_email('registration.txt')
    message = str.format(message % {'name': get_full_name(user)})
    send_out_mail(subject, message, SENDER_EMAIL, [user.email, ])
    pass


def admitted(user):
    subject = "Jelentkezés eredménye"
    message = read_email('admitted.txt')
    message = str.format(message % {'name': get_full_name(user)})
    send_out_mail(subject, message, SENDER_EMAIL, [user.email, ])
    pass


def denied(user):
    subject = "Jelentkezés eredménye"
    message = read_email('denied.txt')
    message = str.format(message % {'name': get_full_name(user)})
    send_out_mail(subject, message, SENDER_EMAIL, [user.email, ])
    pass


def new_homework(user, deadline):
    deadline = deadline.strftime('%Y-%m-%d %H:%M')
    subject = "Új házifeladat"
    message = read_email('new_homework.txt')
    message = str.format(
        message % {'name': get_full_name(user), 'link': HOMEWORK_LINK, 'deadline': deadline})
    send_out_mail(subject, message, SENDER_EMAIL, [user.email, ])
    pass


def homework_corrected(user, title, accepted):
    subject = "Házifeladat eredménye"
    if accepted:
        status = 'Elfogadva'
    else:
        status = 'Hibás'
    message = read_email('homework_corrected.txt')
    message = str.format(message % {'name': get_full_name(user),
                                    'link': HOMEWORK_LINK,
                                    'status': status,
                                    'title': title})
    send_out_mail(subject, message, SENDER_EMAIL, [user.email, ])
    pass
